%%%%%%%%%%%%%%%%%%%%%%%%%
%% A dsolve használata %%
%%%%%%%%%%%%%%%%%%%%%%%%%
close all % ábrák bezárása
%% Differenciálegyenlet megoldása dsolve segítségével
dsolve('Du + u^3*cos(3*t) = 0') % az általános megoldás megadása. Az alapértelmezett változó a 't'.
dsolve('Du + u^3*cos(3*t) = 0', 'u(0) = c') % a konstans meghatározása
ySol = dsolve('Dy = y^2 - 3*y/x', 'y(1) = 2', 'x') % kezdetiérték-feladat megoldása
%% Magasabbrendű differenciálegyenletek megoldása dsolve segítségével
xSol = dsolve('D2x - 2*Dx + 5*x = sin(t)', 'x(0) = c0', 'Dx(0) = c1')
%% Differenciálegyenlet-rendszer megoldása dsolve segítségével
uSol = dsolve('Du1 = -2*u1 + u2 + 3', 'Du2 = -2*u1 -5*u2 -3'); % általános megoldás
uSol.u1 % az egyik függvény
uSol.u2 % a másik függvény
uSol = dsolve('Du1 = -2*u1 + u2 + 3', 'Du2 = -2*u1 -5*u2 -3', 'u1(0) = 3', 'u2(0) = -3'); % kezdetiérték-feladat megoldása
uSol.u1
uSol.u2
return
%% Szimbolikus függvények használata
%% (Újabb matlab-verziók esetén)
syms u1(t) u2(t) % szimbolikus függvények definiálása
u1(t) = uSol.u1
u2(t) = uSol.u2
%% Régi matlab-verziók esetén
% t = [0:0.05:5];
% X = eval(vectorize(uSol.u1));
% Y = eval(vectorize(uSol.u2));
T = 0:0.05:5;
X = u1(T);
Y = u2(T);
figure % a megoldás ábrázolása
subplot(2,1,1);
plot(T,X);
xlabel('t')
ylabel('u1')
subplot(2,1,2);
plot(T,Y);
xlabel('t')
ylabel('u2')
%% Műveletek szimbolikus függvényekkel
syms x(t) xx(t) xxx(t)
x(t) = xSol;
xx(t) = subs(x, {'c0', 'c1'}, {1, 2}) % behelyettesítés
xxx(t) = diff(xx) % deriválás
figure
plot(xx(T), xxx(T))
xlabel('x(t)')
ylabel('x''(t)')
%% Fázistér (számításigényes rész)
uSol = dsolve('Du1 = -2*u1 + u2 + 3', 'Du2 = -2*u1 -5*u2 -3', 'u1(0) = c1', 'u2(0) = c2'); % kezdetiérték-feladat megoldása
syms u1(t) u2(t) u3(t) u4(t)
u1(t) = uSol.u1;
u2(t) = uSol.u2;
figure
hold on
T = 0:0.05:1;
for i = 0:0.5:2
  for j = -2:0.5:0
    u3(t) = subs(u1, {'c1', 'c2'}, {i, j});
    u4(t) = subs(u2, {'c1', 'c2'}, {i, j});
    plot(u3(T), u4(T))
  end
end
hold off
title 'Trajektoriak a fazisterben'
xlabel('u1(t)')
ylabel('u2(t)')
