%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Az EE, IE, ETR, ITR módszerek %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
close all
f = @(t, u) 2 * u.^2 / t;
u_pontos = @(t) -1 ./ (1 + 2*log(t));
t0 = 1;
T = 2;
u0 = -1;
options = optimset('Display', 'off', 'TolFun', 1e-4, 'TolX', 1e-4); % opcionális paraméterek az fsolve függvényhez. Csendes mód, toleranciák.
n = 100;
dt = (T-t0)/n;
uEE = zeros(1, n+1);
uIE = zeros(1, n+1);
uETR = zeros(1, n+1);
uITR = zeros(1, n+1);
uEE(1) = u0;
uIE(1) = u0;
uETR(1) = u0;
uITR(1) = u0;
t = zeros(1, n+1);
t(1) = t0;
for i = 1:n
  t(i+1) = t(i) + dt;
end
for i = 1:n
  uEE(i+1) = uEE(i) + dt * f(t(i), uEE(i));
end
for i = 1:n
  % u(i+1) éppen gIE nullhelye
  gIE = @(u) (u - uIE(i)) - dt * f(t(i+1), u);
  uIE(i+1) = fsolve(gIE, uIE(i), options);
end
for i = 1:n
  uuEE = uETR(i) + dt * f(t(i), uETR(i));
  uETR(i+1) = uETR(i) + dt * 0.5 * (f(t(i), uETR(i)) + f(t(i+1), uuEE));
end
for i = 1:n
  % u(i+1) éppen gITR nullhelye
  gITR = @(u) (u - uITR(i)) - dt * 0.5 * (f(t(i), uITR(i)) + f(t(i+1), u));
  uITR(i+1) = fsolve(gITR, uITR(i), options);
end
figure
hold on
plot(t, uEE, 'b')
plot(t, uIE, 'g')
plot(t, uETR, 'b-.')
plot(t, uITR, 'g-.')
plot(t, u_pontos(t), 'r')
xlabel('t')
ylabel('u')
legend('EE', 'IE', 'ETR', 'ITR', 'pontos')
legend('Location', 'SouthEast')
hold off
