%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Az EE, IE, ETR, ITR módszerek hibája %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
close all
f = @(t, u) 2 * u.^2 / t;
u_pontos = @(t) -1 ./ (1 + 2 * log(t));
t0 = 1;
T = 2;
u0 = -1;
options = optimset('Display', 'off');
errEE = []; % üres mátrix
errIE = [];
errETR = [];
errITR = [];
tdiff = [];
for j = 1:8
  n = 2^j;
  dt = (T-t0)/n;
  uEE = zeros(1, n+1);
  uIE = zeros(1, n+1);
  uETR = zeros(1, n+1);
  uITR = zeros(1, n+1);
  uEE(1) = u0;
  uIE(1) = u0;
  uETR(1) = u0;
  uITR(1) = u0;
  t = zeros(1, n+1);
  t(1) = t0;
  for i = 1:n
    t(i+1) = t(i) + dt;
  end
  for i = 1:n
    uEE(i+1) = uEE(i) + dt * f(t(i), uEE(i));
  end
  for i = 1:n
    % u(i+1) éppen gIE nullhelye
    gIE = @(u) (u - uIE(i)) - dt * f(t(i+1), u);
    uIE(i+1) = fsolve(gIE, uIE(i), options);
  end
  for i = 1:n
    uuEE = uETR(i) + dt * f(t(i), uETR(i));
    uETR(i+1) = uETR(i) + dt * 0.5 * (f(t(i), uETR(i)) + f(t(i+1), uuEE));
  end
  for i = 1:n
    % u(i+1) éppen gITR nullhelye
    gITR = @(u) (u - uITR(i)) - dt * 0.5 * (f(t(i), uITR(i)) + f(t(i+1), u));
    uITR(i+1) = fsolve(gITR, uITR(i), options);
  end
  u = u_pontos(T);
  errEE = [errEE abs(uEE(end) - u(end))];
  errIE = [errIE abs(uIE(end) - u(end))];
  errETR = [errETR abs(uETR(end) - u(end))];
  errITR = [errITR abs(uITR(end) - u(end))];
  tdiff = [tdiff dt];
end
figure
hold on
%% Elsőrendű módszerek
plot(log(tdiff), log(errEE), 'bo--')
plot(log(tdiff), log(errIE), 'go--')
%% Másodrendű módszerek
plot(log(tdiff), log(errETR), 'bo-.')
plot(log(tdiff), log(errITR), 'go-.')
axis equal
xlabel('log(dt)')
ylabel('log(abs(err))')
legend('EE', 'IE', 'ETR', 'ITR')
legend('Location', 'SouthEast')
hold off
