%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Az ode23 és ode45 használata %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
close all
%% Differenciálegyenlet megoldása ode23 és ode45 segítségével
f = @(t, u) 2 * u.^2 / t;
u_p = @(t) -1 ./ (1 + 2 * log(t));
t0 = 1;
tend = 2;
t = t0:0.01:tend;
u0 = -1;
% paraméterek beállítása
% options = odeset('RelTol', 1e-7, 'AbsTol', 1e-8);
% 'options' megadható az ode23 és ode45 függvényeknek mint 4. paraméter
[T23, U23] = ode23(f, [t0, tend], u0);
[T45, U45] = ode45(f, [t0, tend], u0);
% végeredmény
U23(end)
U45(end)
figure
hold on
plot(T23, U23, 'b')
plot(T45, U45, 'g')
plot(t, u_p(t), 'r')
legend('ode23', 'ode45', 'pontos')
legend('Location', 'SouthEast')
title('Automatikus idopontok')
hold off
%% függvény kiértékelése adott időpontokban
[~, u23] = ode23(f, t, u0); % első visszatérési érték eldobása mivel egyenlő t-vel
[~, u45] = ode45(f, t, u0);
% végeredmény
u23(end)
u45(end)
figure
hold on
plot(t, u23, 'b')
plot(t, u45, 'g')
plot(t, u_p(t), 'r')
legend('ode23', 'ode45', 'pontos')
legend('Location', 'SouthEast')
title('Megadott idopontok')
hold off
%% Differenciálegyenlet-rendszer megoldása ode23 és ode45 segítségével
% v1' = -2v1 + v2 + 3
% v2' = -2v1 - 5v2 -3
% v1(0) = 3, v2(0) = -3
% oszlopvektor -> oszlopvektor
g = @(x, v) [-2 1; -2 -5] * v + [3; -3];
v_p = @(x) [2*exp(-3*x) + 1; -2*exp(-3*x) - 1];
x0 = 0;
xend = 1;
v0 = [3; -3];
[X23, V23] = ode23(g, [x0 xend], v0);
[X45, V45] = ode45(g, [x0 xend], v0);
% végeredmény
V23(end,1:2)
V45(end,1:2)
figure
hold on
plot(X23', V23', 'b')
plot(X45', V45', 'g')
plot(0:0.01:1, v_p(0:0.01:1), 'r')
legend('ode23', 'ode23', 'ode45', 'ode45', 'pontos', 'pontos')
legend('Location', 'East')
title('Differencialegyenlet-rendszer')
hold off
